Use ndnpeek and ndnpoke

refs #2858

Change-Id: Idefbe54ac6c5cc0fc9e4a6197f882c027b551a8b
diff --git a/test_multicast/multicast-test.sh b/test_multicast/multicast-test.sh
index 3a2ca00..503c0bd 100755
--- a/test_multicast/multicast-test.sh
+++ b/test_multicast/multicast-test.sh
@@ -37,22 +37,22 @@
 faceid=$(nfd-status -f | grep $a_ipaddr | grep -Po 'faceid=.*? ' | sed 's/faceid=//' | sed 's/ //')
 nfdc add-nexthop ndn:/test-mcast $faceid
 
-# use ndn-tlv-peek to test multicast feature
-response=$(ndn-tlv-peek -p ndn:/test-mcast/B/1)
+# use ndnpeek to test multicast feature
+response=$(ndnpeek -p ndn:/test-mcast/B/1)
 if [[ $response != 'BBBBBBBB' ]]
 then
     echo "FAIL: Expected data for ndn:/test-mcast/B/1 is: 'BBBBBBBB', Actual: '$response'"
     clean_up
     exit 1
 fi
-response=$(ndn-tlv-peek -p ndn:/test-mcast/C/1)
+response=$(ndnpeek -p ndn:/test-mcast/C/1)
 if [[ $response != 'CCCCCCCC' ]]
 then
     echo "FAIL: Expected data for ndn:/test-mcast/C/1 is: 'CCCCCCCC', Actual: '$response'"
     clean_up
     exit 2
 fi
-response=$(ndn-tlv-peek -p ndn:/test-mcast/Z/1)
+response=$(ndnpeek -p ndn:/test-mcast/Z/1)
 if [[ ( $response != 'ZZZZZZZB' ) && ( $response != 'ZZZZZZZC' ) ]]
 then
     echo "FAIL: Expected data for ndn:/test-mcast/Z/1 is: 'ZZZZZZZB' or 'ZZZZZZZC', Actual: '$response'"
@@ -63,8 +63,8 @@
 # kill ndn-traffic-server on host B
 ssh $CTRL_B "sudo killall ndn-traffic-server"
 
-# use ndn-tlv-peek to request ndn:/testmcast/Z/2
-response=$(ndn-tlv-peek -p ndn:/test-mcast/Z/2)
+# use ndnpeek to request ndn:/testmcast/Z/2
+response=$(ndnpeek -p ndn:/test-mcast/Z/2)
 if [[ $response != 'ZZZZZZZC' ]]
 then
     echo "FAIL: Expected data for ndn:/test-mcast/Z/2 is: 'ZZZZZZZC', Actual: '$response'"